# Amazon Linux2023安装XtraBackup2.4

**URL:** <https://forums.percona.com/t/amazon-linux2023-xtrabackup2-4/40650>\
**Category:** MySQL & MariaDB\
**Created:** [April 17, 2026, 10:22am UTC](https://forums.percona.com/t/amazon-linux2023-xtrabackup2-4/40650 "2026-04-17T10:22:30Z")\
**Posts on this page:** 14\
**Page:** 1

<div class="post-metadata">

**Author:** ![ddf](https://avatars.discourse-cdn.com/v4/letter/d/f475e1/32.png) [@ddf](https://forums.percona.com/u/ddf)\
**Post date:** [April 17, 2026, 10:22am UTC](https://forums.percona.com/t/amazon-linux2023-xtrabackup2-4/40650/1 "2026-04-17T10:22:30Z")

</div>

Amazon Linux2023安装XtraBackup2.4失败，  
安装之后显示：

[root@ip-172-31-37-135 bin]# sudo yum install [https://repo.percona.com/yum/percona-release-latest.noarch.rpm](https://repo.percona.com/yum/percona-release-latest.noarch.rpm)  
Last metadata expiration check: 2:00:08 ago on Fri Apr 17 06:02:21 2026.  
percona-release-latest.noarch.rpm 496 kB/s | 28 kB 00:00  
Package percona-release-1.0-32.noarch is already installed.  
Dependencies resolved.  
Nothing to do.  
Complete!  
[root@ip-172-31-37-135 bin]# sudo percona-release enable-only pxb-24 release  
Specified repository is not supported for current operating system!  
[root@ip-172-31-37-135 bin]# sudo yum install percona-xtrabackup-24  
Last metadata expiration check: 2:00:32 ago on Fri Apr 17 06:02:21 2026.  
Package percona-xtrabackup-24-2.4.28-1.el9.x86\_64 is already installed.  
Dependencies resolved.  
Nothing to do.  
Complete!  
[root@ip-172-31-37-135 bin]# xtrabackup --version  
xtrabackup: /lib64/libgcrypt.so.11: version `GCRYPT\_1.2’ not found (required by xtrabackup)  
[root@ip-172-31-37-135 bin]# xtrabackup --version  
xtrabackup: /lib64/libgcrypt.so.11: version `GCRYPT\_1.2’ not found (required by xtrabackup)  
[root@ip-172-31-37-135 bin]#

xtrabackup --version

xtrabackup: /lib64/libgcrypt.so.11: version `GCRYPT\_1.2’ not found (required by xtrabackup)

请问Amazon Linux2023可以通过什么方式安装兼容的XtraBackup2.4来备份MySQL5.7？

---

<div class="post-metadata">

**Author:** ![anil.joshi](https://sea1.discourse-cdn.com/flex019/user_avatar/forums.percona.com/anil.joshi/32/13100_2.png) [@anil.joshi](https://forums.percona.com/u/anil.joshi)\
**Post date:** [April 18, 2026, 2:01pm UTC](https://forums.percona.com/t/amazon-linux2023-xtrabackup2-4/40650/2 "2026-04-18T14:01:53Z")

</div>

@ddf

It seems the package is not available via the Yum repository.

```auto
root@ip-172-31-20-211 ~]# cat /etc/os-release
NAME="Amazon Linux"
VERSION="2023"
ID="amzn"
ID_LIKE="fedora"
VERSION_ID="2023"
PLATFORM_ID="platform:al2023"
PRETTY_NAME="Amazon Linux 2023.11.20260413"
ANSI_COLOR="0;33"
CPE_NAME="cpe:2.3:o:amazon:amazon_linux:2023"
HOME_URL="https://aws.amazon.com/linux/amazon-linux-2023/"
DOCUMENTATION_URL="https://docs.aws.amazon.com/linux/"
SUPPORT_URL="https://aws.amazon.com/premiumsupport/"
BUG_REPORT_URL="https://github.com/amazonlinux/amazon-linux-2023"
VENDOR_NAME="AWS"
VENDOR_URL="https://aws.amazon.com/"
SUPPORT_END="2029-06-30"

```

`sudo yum install https://repo.percona.com/yum/percona-release-latest.noarch.rpm`

```auto
[root@ip-172-31-20-211 ~]# yum list | grep percona
percona-release.noarch 1.0-32 @@commandline           
percona-telemetry-agent.x86_64

```

However, installing it via direct RPM works fine for me.

` wget https://downloads.percona.com/downloads/Percona-XtraBackup-2.4/Percona-XtraBackup-2.4.28/binary/redhat/9/x86_64/percona-xtrabackup-24-2.4.28-1.el9.x86_64.rpm`

```auto
[root@ip-172-31-20-211 ~]# yum localinstall percona-xtrabackup-24-2.4.28-1.el9.x86_64.rpm
Last metadata expiration check: 0:02:58 ago on Sat Apr 18 13:48:50 2026.
Dependencies resolved.
======================================================================================================================================================================================================================
 Package Architecture Version Repository Size
======================================================================================================================================================================================================================
Installing:
 percona-xtrabackup-24 x86_64 2.4.28-1.el9 @commandline 6.9 M
Installing dependencies:
 mariadb-connector-c x86_64 3.3.10-1.amzn2023.0.1 amazonlinux 211 k
 mariadb-connector-c-config noarch 3.3.10-1.amzn2023.0.1 amazonlinux 9.9 k
 perl-DBD-MySQL x86_64 4.050-10.amzn2023.0.2 amazonlinux 145 k
 perl-DBI x86_64 1.643-7.amzn2023.0.3 amazonlinux 700 k
 perl-Math-BigInt noarch 1:1.9998.39-2.amzn2023.0.2 amazonlinux 202 k
 perl-Math-BigRat noarch 0.2624-500.amzn2023.0.2 amazonlinux 42 k
 perl-Math-Complex noarch 1.59-477.amzn2023.0.7 amazonlinux 46 k

Transaction Summary
======================================================================================================================================================================================================================
Install 8 Packages

Total size: 8.2 M
Total download size: 1.3 M
Installed size: 35 M
Is this ok [y/N]: y
Downloading Packages:
(1/7): mariadb-connector-c-config-3.3.10-1.amzn2023.0.1.noarch.rpm 247 kB/s | 9.9 kB 00:00    
(2/7): mariadb-connector-c-3.3.10-1.amzn2023.0.1.x86_64.rpm 4.4 MB/s | 211 kB 00:00    
(3/7): perl-DBD-MySQL-4.050-10.amzn2023.0.2.x86_64.rpm 2.5 MB/s | 145 kB 00:00    
(4/7): perl-DBI-1.643-7.amzn2023.0.3.x86_64.rpm 26 MB/s | 700 kB 00:00    
(5/7): perl-Math-BigInt-1.9998.39-2.amzn2023.0.2.noarch.rpm 6.6 MB/s | 202 kB 00:00    
(6/7): perl-Math-BigRat-0.2624-500.amzn2023.0.2.noarch.rpm 1.8 MB/s | 42 kB 00:00    
(7/7): perl-Math-Complex-1.59-477.amzn2023.0.7.noarch.rpm 1.6 MB/s | 46 kB 00:00    
----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
Total 9.1 MB/s | 1.3 MB 00:00     
Running transaction check
Transaction check succeeded.
Running transaction test
Transaction test succeeded.
Running transaction
  Preparing : 1/1 
  Installing : perl-Math-Complex-1.59-477.amzn2023.0.7.noarch 1/8 
  Installing : perl-Math-BigRat-0.2624-500.amzn2023.0.2.noarch 2/8 
  Installing : perl-Math-BigInt-1:1.9998.39-2.amzn2023.0.2.noarch 3/8 
  Installing : perl-DBI-1.643-7.amzn2023.0.3.x86_64 4/8 
  Installing : mariadb-connector-c-config-3.3.10-1.amzn2023.0.1.noarch 5/8 
  Installing : mariadb-connector-c-3.3.10-1.amzn2023.0.1.x86_64 6/8 
  Installing : perl-DBD-MySQL-4.050-10.amzn2023.0.2.x86_64 7/8 
  Installing : percona-xtrabackup-24-2.4.28-1.el9.x86_64 8/8 
  Running scriptlet: percona-xtrabackup-24-2.4.28-1.el9.x86_64 8/8 
  Verifying : mariadb-connector-c-3.3.10-1.amzn2023.0.1.x86_64 1/8 
  Verifying : mariadb-connector-c-config-3.3.10-1.amzn2023.0.1.noarch 2/8 
  Verifying : perl-DBD-MySQL-4.050-10.amzn2023.0.2.x86_64 3/8 
  Verifying : perl-DBI-1.643-7.amzn2023.0.3.x86_64 4/8 
  Verifying : perl-Math-BigInt-1:1.9998.39-2.amzn2023.0.2.noarch 5/8 
  Verifying : perl-Math-BigRat-0.2624-500.amzn2023.0.2.noarch 6/8 
  Verifying : perl-Math-Complex-1.59-477.amzn2023.0.7.noarch 7/8 
  Verifying : percona-xtrabackup-24-2.4.28-1.el9.x86_64 8/8 

Installed:
  mariadb-connector-c-3.3.10-1.amzn2023.0.1.x86_64 mariadb-connector-c-config-3.3.10-1.amzn2023.0.1.noarch percona-xtrabackup-24-2.4.28-1.el9.x86_64 perl-DBD-MySQL-4.050-10.amzn2023.0.2.x86_64      
  perl-DBI-1.643-7.amzn2023.0.3.x86_64 perl-Math-BigInt-1:1.9998.39-2.amzn2023.0.2.noarch perl-Math-BigRat-0.2624-500.amzn2023.0.2.noarch perl-Math-Complex-1.59-477.amzn2023.0.7.noarch   

Complete!

```

```auto
**yum list | grep percona**
percona-release.noarch 1.0-32 @@commandline           
percona-xtrabackup-24.x86_64 2.4.28-1.el9 @@commandline           
percona-telemetry-agent.x86_64 1.0.11-1.amzn2023 telemetry-release-x86_64

```

```auto
**[root@ip-172-31-20-211 ~]# xtrabackup --version**
xtrabackup: recognized server arguments: 
xtrabackup version 2.4.28 based on MySQL server 5.7.40 Linux (x86_64) (revision id: 44a8f7b)

```

Can you try installing it via RPM - [Installing Percona XtraBackup on Red Hat Enterprise Linux and CentOS - Percona XtraBackup](https://docs.percona.com/percona-xtrabackup/2.4/installation/yum_repo.html#installing-percona-xtrabackup-using-downloaded-rpm-packages) and let us know if that works or still getting any errors ?

---

<div class="post-metadata">

**Author:** ![ddf](https://avatars.discourse-cdn.com/v4/letter/d/f475e1/32.png) [@ddf](https://forums.percona.com/u/ddf)\
**Post date:** [April 20, 2026, 12:40am UTC](https://forums.percona.com/t/amazon-linux2023-xtrabackup2-4/40650/3 "2026-04-20T00:40:31Z")

</div>

> [@anil.joshi](#):
>
> `yum localinstall percona-xtrabackup-24-2.4.28-1.el9.x86_64.rpm`

[root@ip-172-31-37-135 ~]# cat /etc/os-release  
NAME=“Amazon Linux”  
VERSION=“2023”  
ID=“amzn”  
ID\_LIKE=“fedora”  
VERSION\_ID=“2023”  
PLATFORM\_ID=“platform:al2023”  
PRETTY\_NAME=“Amazon Linux 2023.8.20250715”  
ANSI\_COLOR=“0;33”  
CPE\_NAME=“cpe:2.3:o:amazon:amazon\_linux:2023”  
HOME\_URL=“[Linux for the Cloud – Amazon Linux 2023 – Amazon Web Services](https://aws.amazon.com/linux/amazon-linux-2023/)”  
DOCUMENTATION\_URL=“[https://docs.aws.amazon.com/linux/](https://docs.aws.amazon.com/linux/)”  
SUPPORT\_URL=“[AI-powered cloud support – AWS Support plans – AWS](https://aws.amazon.com/premiumsupport/)”  
BUG\_REPORT\_URL=“[GitHub - amazonlinux/amazon-linux-2023: Amazon Linux 2023 · GitHub](https://github.com/amazonlinux/amazon-linux-2023)”  
VENDOR\_NAME=“AWS”  
VENDOR\_URL=“[https://aws.amazon.com/](https://aws.amazon.com/)”  
SUPPORT\_END=“2029-06-30”  
[root@ip-172-31-37-135 ~]# wget [https://downloads.percona.com/downloads/Percona-XtraBackup-2.4/Percona-XtraBackup-2.4.28/binary/redhat/9/x86\_64/percona-xtrabackup-24-2.4.28-1.el9.x86\_64.rpm](https://downloads.percona.com/downloads/Percona-XtraBackup-2.4/Percona-XtraBackup-2.4.28/binary/redhat/9/x86_64/percona-xtrabackup-24-2.4.28-1.el9.x86_64.rpm)  
–2026-04-20 00:39:25-- [https://downloads.percona.com/downloads/Percona-XtraBackup-2.4/Percona-XtraBackup-2.4.28/binary/redhat/9/x86\_64/percona-xtrabackup-24-2.4.28-1.el9.x86\_64.rpm](https://downloads.percona.com/downloads/Percona-XtraBackup-2.4/Percona-XtraBackup-2.4.28/binary/redhat/9/x86_64/percona-xtrabackup-24-2.4.28-1.el9.x86_64.rpm)  
Resolving [downloads.percona.com](http://downloads.percona.com) ([downloads.percona.com](http://downloads.percona.com))… 147.135.54.159, 2604:2dc0:200:69f::2  
Connecting to [downloads.percona.com](http://downloads.percona.com) ([downloads.percona.com](http://downloads.percona.com))|147.135.54.159|:443… connected.  
HTTP request sent, awaiting response… 200 OK  
Length: 7207675 (6.9M) [application/x-redhat-package-manager]  
Saving to: ‘percona-xtrabackup-24-2.4.28-1.el9.x86\_64.rpm.1’

percona-xtrabackup-24-2.4.28-1.el9.x86\_64.rpm.1 100%[=================================================================================================================================================================\>] 6.87M 42.6MB/s in 0.2s

2026-04-20 00:39:26 (42.6 MB/s) - ‘percona-xtrabackup-24-2.4.28-1.el9.x86\_64.rpm.1’ saved [7207675/7207675]

[root@ip-172-31-37-135 ~]# yum localinstall percona-xtrabackup-24-2.4.28-1.el9.x86\_64.rpm  
Last metadata expiration check: 3:42:22 ago on Sun Apr 19 20:57:30 2026.  
Package percona-xtrabackup-24-2.4.28-1.el9.x86\_64 is already installed.  
Dependencies resolved.  
Nothing to do.  
Complete!  
[root@ip-172-31-37-135 ~]#  
这种方式依旧不支持安装

---

<div class="post-metadata">

**Author:** ![ddf](https://avatars.discourse-cdn.com/v4/letter/d/f475e1/32.png) [@ddf](https://forums.percona.com/u/ddf)\
**Post date:** [April 20, 2026, 12:42am UTC](https://forums.percona.com/t/amazon-linux2023-xtrabackup2-4/40650/4 "2026-04-20T00:42:25Z")

</div>

[root@ip-172-31-37-135 ~]# yum install -y percona-xtrabackup-24.x86\_64  
Last metadata expiration check: 3:44:00 ago on Sun Apr 19 20:57:30 2026.  
Package percona-xtrabackup-24-2.4.28-1.el9.x86\_64 is already installed.  
Dependencies resolved.  
Nothing to do.  
Complete!  
[root@ip-172-31-37-135 ~]# xtrabackup --version  
xtrabackup: /lib64/libgcrypt.so.11: version `GCRYPT\_1.2’ not found (required by xtrabackup)  
[root@ip-172-31-37-135 ~]#

---

<div class="post-metadata">

**Author:** ![hai.nguyen](https://avatars.discourse-cdn.com/v4/letter/h/41988e/32.png) [@hai.nguyen](https://forums.percona.com/u/hai.nguyen)\
**Post date:** [April 20, 2026, 1:38am UTC](https://forums.percona.com/t/amazon-linux2023-xtrabackup2-4/40650/5 "2026-04-20T01:38:51Z")

</div>

Hi @ddf,

What is the current version of libgcrypt on your server?

```auto
rpm -qf /lib64/libgcrypt.so.11

```

It is working for me with libgcrypt-1.10.2-1.amzn2023.0.2.x86\_64:

```auto
# xtrabackup --version
xtrabackup: recognized server arguments:
xtrabackup version 2.4.28 based on MySQL server 5.7.40 Linux (x86_64) (revision id: 44a8f7b)

# ldd /usr/bin/xtrabackup | grep -i gcrypt
	libgcrypt.so.20 => /lib64/libgcrypt.so.20 (0x00007f2b81259000)

# rpm -qf /lib64/libgcrypt.so.20
libgcrypt-1.10.2-1.amzn2023.0.2.x86_64

```

Try updating libgcrypt on your server:

```auto
sudo dnf update libgcrypt

```

---

<div class="post-metadata">

**Author:** ![ddf](https://avatars.discourse-cdn.com/v4/letter/d/f475e1/32.png) [@ddf](https://forums.percona.com/u/ddf)\
**Post date:** [April 20, 2026, 1:42am UTC](https://forums.percona.com/t/amazon-linux2023-xtrabackup2-4/40650/6 "2026-04-20T01:42:02Z")

</div>

> [@hai.nguyen](#):
>
> libgcrypt当前版本

[root@ip-172-31-37-135 scripts]# rpm -qa | grep libgcrypt  
libgcrypt-1.10.2-1.amzn2023.0.2.x86\_64  
[root@ip-172-31-37-135 scripts]#  
我是这个版本，显示不兼容  
[root@ip-172-31-37-135 scripts]# xtrabackup --version  
xtrabackup: /lib64/libgcrypt.so.11: version `GCRYPT\_1.2’ not found (required by xtrabackup)  
[root@ip-172-31-37-135 scripts]#

---

<div class="post-metadata">

**Author:** ![hai.nguyen](https://avatars.discourse-cdn.com/v4/letter/h/41988e/32.png) [@hai.nguyen](https://forums.percona.com/u/hai.nguyen)\
**Post date:** [April 20, 2026, 1:54am UTC](https://forums.percona.com/t/amazon-linux2023-xtrabackup2-4/40650/7 "2026-04-20T01:54:34Z")

</div>

Please execute and share the outputs for these commands:

```auto
ls -la /lib64/libgcrypt.so*
rpm -qf /lib64/libgcrypt.so.11

```

---

<div class="post-metadata">

**Author:** ![ddf](https://avatars.discourse-cdn.com/v4/letter/d/f475e1/32.png) [@ddf](https://forums.percona.com/u/ddf)\
**Post date:** [April 20, 2026, 1:57am UTC](https://forums.percona.com/t/amazon-linux2023-xtrabackup2-4/40650/8 "2026-04-20T01:57:16Z")

</div>

> [@hai.nguyen](#):
>
> `rpm -qf /lib64/libgcrypt.so.11`

[root@ip-172-31-37-135 incremental]# ls -la /lib64/libgcrypt.so\*  
lrwxrwxrwx. 1 root root 26 Apr 17 05:57 /lib64/libgcrypt.so.11 → /usr/lib64/libgcrypt.so.20  
lrwxrwxrwx. 1 root root 19 Oct 4 2024 /lib64/libgcrypt.so.20 → libgcrypt.so.20.4.2  
-rwxr-xr-x. 1 root root 1348296 Oct 4 2024 /lib64/libgcrypt.so.20.4.2  
[root@ip-172-31-37-135 incremental]# rpm -qf /lib64/libgcrypt.so.11  
file /lib64/libgcrypt.so.11 is not owned by any package  
[root@ip-172-31-37-135 incremental]#

---

<div class="post-metadata">

**Author:** ![hai.nguyen](https://avatars.discourse-cdn.com/v4/letter/h/41988e/32.png) [@hai.nguyen](https://forums.percona.com/u/hai.nguyen)\
**Post date:** [April 20, 2026, 2:08am UTC](https://forums.percona.com/t/amazon-linux2023-xtrabackup2-4/40650/9 "2026-04-20T02:08:50Z")

</div>

```auto
lrwxrwxrwx. 1 root root 26 Apr 17 05:57 /lib64/libgcrypt.so.11 → /usr/lib64/libgcrypt.so.20

```

Did you manually create this symlink?

Please try removing it:

```auto
rm -f /lib64/libgcrypt.so.11

```

---

<div class="post-metadata">

**Author:** ![ddf](https://avatars.discourse-cdn.com/v4/letter/d/f475e1/32.png) [@ddf](https://forums.percona.com/u/ddf)\
**Post date:** [April 20, 2026, 2:14am UTC](https://forums.percona.com/t/amazon-linux2023-xtrabackup2-4/40650/10 "2026-04-20T02:14:06Z")

</div>

[root@ip-172-31-37-135 incremental]# ls -la /lib64/libgcrypt.so\*  
lrwxrwxrwx. 1 root root 26 Apr 17 05:57 /lib64/libgcrypt.so.11 → /usr/lib64/libgcrypt.so.20  
lrwxrwxrwx. 1 root root 19 Oct 4 2024 /lib64/libgcrypt.so.20 → libgcrypt.so.20.4.2  
-rwxr-xr-x. 1 root root 1348296 Oct 4 2024 /lib64/libgcrypt.so.20.4.2  
[root@ip-172-31-37-135 incremental]# rpm -qf /lib64/libgcrypt.so.11  
file /lib64/libgcrypt.so.11 is not owned by any package  
[root@ip-172-31-37-135 incremental]# rm -f /lib64/libgcrypt.so.11  
[root@ip-172-31-37-135 incremental]# xtrabackup --version  
xtrabackup: error while loading shared libraries: libgcrypt.so.11: cannot open shared object file: No such file or directory  
[root@ip-172-31-37-135 incremental]# ls -la /lib64/libgcrypt.so\*  
lrwxrwxrwx. 1 root root 19 Oct 4 2024 /lib64/libgcrypt.so.20 → libgcrypt.so.20.4.2  
-rwxr-xr-x. 1 root root 1348296 Oct 4 2024 /lib64/libgcrypt.so.20.4.2  
[root@ip-172-31-37-135 incremental]# xtrabackup --version  
xtrabackup: error while loading shared libraries: libgcrypt.so.11: cannot open shared object file: No such file or directory  
[root@ip-172-31-37-135 incremental]#  
删除了还是不兼容

---

<div class="post-metadata">

**Author:** ![hai.nguyen](https://avatars.discourse-cdn.com/v4/letter/h/41988e/32.png) [@hai.nguyen](https://forums.percona.com/u/hai.nguyen)\
**Post date:** [April 20, 2026, 2:47am UTC](https://forums.percona.com/t/amazon-linux2023-xtrabackup2-4/40650/11 "2026-04-20T02:47:48Z")

</div>

Do you have multiple xtrabackup binaries installed?

Please share these outputs:

```auto
whereis xtrabackup
type -a xtrabackup
rpm -qi percona-xtrabackup-24
ldd "$(command -v xtrabackup)" | grep -Ei 'gcrypt|ssl|crypto'
readelf -d "$(command -v xtrabackup)" | grep NEEDED
sha256sum "$(command -v xtrabackup)"

```

---

<div class="post-metadata">

**Author:** ![ddf](https://avatars.discourse-cdn.com/v4/letter/d/f475e1/32.png) [@ddf](https://forums.percona.com/u/ddf)\
**Post date:** [April 20, 2026, 2:49am UTC](https://forums.percona.com/t/amazon-linux2023-xtrabackup2-4/40650/12 "2026-04-20T02:49:43Z")

</div>

感谢你的回复，我已经通过docker的方式解决了[Amazon Linux2023安装XtraBackup2.4](https://forums.percona.com/t/amazon-linux2023-xtrabackup2-4/40650)不兼容的问题。

---

<div class="post-metadata">

**Author:** ![hai.nguyen](https://avatars.discourse-cdn.com/v4/letter/h/41988e/32.png) [@hai.nguyen](https://forums.percona.com/u/hai.nguyen)\
**Post date:** [April 20, 2026, 3:03am UTC](https://forums.percona.com/t/amazon-linux2023-xtrabackup2-4/40650/13 "2026-04-20T03:03:08Z")

</div>

Yep, running xtrabackup in Docker works as well. Please refer to our documentation for setup details: [Running Percona XtraBackup in a Docker container - Percona XtraBackup](https://docs.percona.com/percona-xtrabackup/2.4/installation/docker.html)

---

<div class="post-metadata">

**Author:** ![Evgeniy\_Patlan](https://sea1.discourse-cdn.com/flex019/user_avatar/forums.percona.com/evgeniy_patlan/32/41_2.png) [@Evgeniy\_Patlan](https://forums.percona.com/u/Evgeniy_Patlan)\
**Post date:** [April 22, 2026, 7:29pm UTC](https://forums.percona.com/t/amazon-linux2023-xtrabackup2-4/40650/14 "2026-04-22T19:29:43Z")

</div>

For Percona Xtrabackup 2.4 the only possible way to run on AL2023 is docker. We added support for AL2023 later
